# Changelog

All notable changes to this project will be documented in this file.

## [0.1.5] - 2026-03-29

### Features

- *(docx)* Add DOCX generation from IR ([336ab40](https://github.com/ThomAub/officemd/commit/336ab40b1e773d14ad4b2a4d9e814cf2efa85ec7))

### Miscellaneous

- Release v0.1.4 ([1289d01](https://github.com/ThomAub/officemd/commit/1289d011ddbda12b4891b784eaf2b92bf843f979))

